soledad Package
===============

:mod:`soledadbootstrapper` Module
---------------------------------

.. automodule:: leap.services.soledad.soledadbootstrapper
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`soledadconfig` Module
---------------------------

.. automodule:: leap.services.soledad.soledadconfig
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`soledadspec` Module
-------------------------

.. automodule:: leap.services.soledad.soledadspec
    :members:
    :undoc-members:
    :show-inheritance:

